use clap::Parser;
use eternalfest_cli::cmd::dump;

#[tokio::main]
async fn main() {
  let args: dump::DumpArgs = dump::DumpArgs::parse();

  let res = dump::dump(&args).await;

  match res {
    Err(e) => {
      eprintln!("{}", e);
    }
    Ok(()) => {}
  }
}
